@@ -1,4 +1,5 @@
-from generallibrary import NetworkDiagram
+from generalfile import Path
+from generallibrary import NetworkDiagram, Log
 
 from generalpackager.api.localrepo.base.localrepo_target import _SharedTarget
 from generalpackager.api.shared import _SharedAPI, _SharedName, _SharedPath
@@ -23,11 +24,12 @@ class Packager(NetworkDiagram,
     email = "rickard.abraham@gmail.com"
     license = "mit"
     python = "3.8", "3.9"  # Only supports basic definition with tuple of major.minor
+    # python = "3.8", "3.9", "3.10"  # Only supports basic definition with tuple of major.minor
     os = "windows", "ubuntu"  # , "macos"
 
-    git_exclude_lines = npm_ignore_lines = ".idea", "dist", ".git", "test/tests", ".coverage"
-    git_exclude_lines += "build", "*.egg-info", "__pycache__", "PKG-INFO", "setup.cfg"
-    npm_ignore_lines += "node_modules", ".parcel-cache"
+    git_exclude_lines = npm_ignore_lines = ".idea/", "dist/", ".git/", "**test/tests/", ".coverage"
+    git_exclude_lines += "build/", "*.egg-info/", "__pycache__/", "PKG-INFO/", "setup.cfg"
+    npm_ignore_lines += "node_modules/", ".parcel-cache/"
 
     Packages = Packages
 
@@ -38,6 +40,33 @@ class Packager(NetworkDiagram,
         self._pypi_owner = pypi_owner
 
 
+    @classmethod
+    def packagers_from_packages(cls):
+        """ Get all packagers defined in Packages even if they don't exist.
+            Paths are set to working_dir / name. """
+        packagers = []
+        for target, names in cls.Packages.field_dict_defaults().items():
+            for name in names:
+                packager = Packager(name=name, path=name, target=target)
+                packagers.append(packager)
+        return packagers
+
+    @classmethod
+    def new_clean_environment(cls, path=None):
+        """ Creates a new clean environment for the packages.
+            Clones all into a (preferably empty) specified folder.
+            Create and activate new venv.
+            Install python packages as editable. """
+        path = Path(path)
+        assert path.empty()
+
+        with path.as_working_dir():
+            packagers = cls.packagers_from_packages()
+
+            for packager in packagers:
+                Log(__name__).info(f"Downloading {packager.name} from GitHub.")
+                packager.github.download()
+
     @staticmethod
     def summary_packagers():
         """ Packagers to hold summary of environment. """
