@@ -22,7 +22,9 @@ class GenerateFile:
     def generate(self):
         """ Generate actual file. """
         if self.overwrite or not self.path.exists():
-            self.path.text.write(f"{self.text_func()}\n", overwrite=self.overwrite)
+            text = self.text_func()
+            assert text is not None
+            self.path.text.write(f"{text}\n", overwrite=self.overwrite)
 
     def __str__(self):
         return f"<GenerateFile: {self.packager.name} - {self.relative_path}>"
@@ -47,6 +49,7 @@ class _PackagerFiles:
             GenerateFile(self.localrepo.get_workflow_path(), self.generate_workflow, self, aesthetic=True),
             GenerateFile(self.localrepo.get_readme_path(), self.generate_readme, self, aesthetic=True),
             GenerateFile(self.localrepo.get_generate_path(), self.generate_generate, self, aesthetic=True),
+            GenerateFile(self.localrepo.get_pre_commit_hook_path(), self.generate_pre_commit, self, aesthetic=True),
         ]
 
         if self.is_python():
@@ -109,6 +112,7 @@ class _PackagerFiles:
     @classmethod
     def create_blank_locally_python(cls, path, install=True):
         """ Create a new general package locally only.
+            Todo: Fix create_blank, it overwrites current projects pip install.
 
             :param generalpackager.Packager or Any cls:
             :param Path or str path:
@@ -123,8 +127,10 @@ class _PackagerFiles:
         if install:
             packager.localrepo.pip_install_editable()
 
-        new_self = packager.get_new_packager()  # Reset caches to get updated files
-        new_self.generate_localfiles()
+        # new_self = packager.get_new_packager()  # Reset caches to get updated files
+        # new_self.generate_localfiles()
+
+        return packager
 
     def relative_path_is_aesthetic(self, relative_path):
         """ Relative to package path. False if not defined as a GenerateFile instance.
@@ -282,18 +288,24 @@ class _PackagerFiles:
         # Description
         markdown = self.get_description_markdown()
 
-        # Information
-        self.get_information_markdown().set_parent(parent=markdown)
-
         # Table of contents
         contents = Markdown(header="Contents", parent=markdown)
 
+        # Examples
+        self.get_examples_markdown().set_parent(parent=markdown)
+
         # Installation
         self.get_installation_markdown().set_parent(parent=markdown)
 
+        # Information
+        self.get_information_markdown().set_parent(parent=markdown)
+
         # Attributes
         self.get_attributes_markdown().set_parent(parent=markdown)
 
+        # Contributions
+        self.get_contributions_markdown().set_parent(parent=markdown)
+
         # Todos
         self.get_todos_markdown(self, drop_package_col=True).set_parent(parent=markdown)
 
@@ -312,7 +324,6 @@ class _PackagerFiles:
         # ordered_packagers = type(self)().get_ordered_packagers()
         ordered_packagers = self.get_ordered_packagers(include_private=False)
 
-
         # Description
         markdown = Markdown(header="ManderaGeneral").add_list_lines(
             "A collection of connected packages.",
@@ -357,6 +368,18 @@ class _PackagerFiles:
 
         return top
 
+    def generate_pre_commit(self):
+        """ Generate test template.
+
+            :param generalpackager.Packager self: """
+        top = CodeLine()
+
+        top.add_node(CodeLine("#!/usr/bin/env python"))
+        top.add_node(CodeLine(f"from generalpackager import Packager", space_before=1))
+        top.add_node(CodeLine(f"Packager(\"{self.name}\").generate_localfiles(aesthetic=False, error_on_change=True)", space_before=1))
+
+        return top
+
     def generate_test_python(self):
         """ Generate test template.
 
@@ -418,25 +441,36 @@ class _PackagerFiles:
         }
         return json.dumps(info, indent=4)
 
-    def generate_localfiles(self, aesthetic=True, print_out=False):
+    def generate_localfiles(self, aesthetic=True, print_out=False, error_on_change=False):
         """ Generate all local files.
+            Returns True if any file is changed.
 
             :param aesthetic:
             :param generalpackager.Packager self:
-            :param print_out: """
+            :param print_out:
+            :param error_on_change: """
         timer = Timer()
 
         # Not in files because it writes with json not text, it's also a bit unique
-        self.localrepo.metadata.write_config()
+        self.localrepo.metadata.name = self.name
+        # self.localrepo.metadata.write_config()
 
-        for generate in self.files:
-            if aesthetic or not generate.aesthetic:
-                if print_out:
-                    print(f"Generating {generate}")
-                generate.generate()
+        files = [file for file in self.files if aesthetic or not file.aesthetic]
+
+        for file in files:
+            if print_out:
+                print(f"Generating {file}")
+            file.generate()
         if print_out:
             timer.print()
 
+        if error_on_change:
+            file_paths = {file.path for file in files}
+            changed_files = {path.absolute() for path in self.localrepo.git_changed_files()}
+
+            changed_generated_files = file_paths.intersection(changed_files)
+            if changed_generated_files:
+                raise EnvironmentError(f"Files changed: {changed_generated_files}")
 
 
 
