@@ -80,15 +80,14 @@ class _PackagerMarkdown:
         markdown = Markdown(header=self._todo_header)
         if todos:
             markdown.add_table_lines(*todos)
-        else:
-            markdown.add_node("No todos!")
         return markdown
 
     def get_description_markdown(self):
         """ :param generalpackager.Packager self: """
         part_of = f"This package and {len(self.get_all()) - 1} other make up {Markdown.link(text='ManderaGeneral', url='https://github.com/ManderaGeneral')}."
 
-        return Markdown(self.localrepo.metadata.description, "\n", part_of, header=self.name)
+        return Markdown(self.localrepo.metadata.description, header=self.name)
+        # return Markdown(self.localrepo.metadata.description, "\n", part_of, header=self.name)
 
     def get_information_markdown(self, *packagers):
         """ Get information table.
@@ -144,13 +143,17 @@ class _PackagerMarkdown:
 
         return markdown
 
+    @staticmethod
+    def _filt(markdown):
+        return markdown.header
+
     def _configure_contents_markdown(self, markdown):
         """ Configure table of contents lines from markdown.
 
             :param generalpackager.Packager self:
-            :param markdown: """
+            :param Markdown markdown: """
         parent_markdown = markdown.get_parent(-1, -1)
-        markdown.add_pre_lines(parent_markdown.view(custom_repr=lambda md: md.link(md.header, href=True), print_out=False))
+        markdown.add_pre_lines(parent_markdown.view(custom_repr=lambda md: md.link(md.header, href=True), print_out=False, filt=self._filt))
         return markdown
 
     def github_link(self, text, suffix):
@@ -220,3 +223,66 @@ class _PackagerMarkdown:
 
         return Markdown(line).wrap_with_tags("sup")
 
+    @staticmethod
+    def _docstring_markdown(docstrings, index, parent):
+        if len(docstrings) > index:
+            docstring = docstrings[index]
+            docstring = docstring.replace('"""', "")
+            docstring_lines = [line.strip() for line in docstring.splitlines(keepends=True)]
+            docstring_markdown = Markdown(parent=parent)
+            docstring_markdown.add_lines(*docstring_lines)
+            return docstring_markdown
+
+    def _header_from_path(self, path):
+        stem = path.stem()
+        if stem[0].isdigit():
+            stem = stem[1:]
+        header = stem.replace("_", " ").title()
+        return header
+
+    def get_examples_markdown(self):
+        """ Read examples folder and convert to markdown.
+            Might wanna sort by alphabetical or something.
+
+            :param generalpackager.Packager self: """
+        markdown = Markdown(header="Examples")
+        paths = self.localrepo.get_examples_path().get_children()
+        sorted_paths = sorted(paths, key=lambda path: path.name())
+        for path in sorted_paths:  # type: Path
+            example = Markdown(header=self._header_from_path(path=path), parent=markdown)
+
+            lines = path.text.read()
+            docstrings = re.findall(r'""".*?"""', lines, flags=re.S)
+
+            self._docstring_markdown(docstrings=docstrings, index=0, parent=example)
+
+            code = re.sub(r'""".*?"""', "", lines, flags=re.S)
+            code_lines = code.strip().splitlines(keepends=True)
+            if code_lines:
+                code_markdown = Markdown(parent=example)
+                code_markdown.add_code_lines(*code_lines, lang="python")
+
+            self._docstring_markdown(docstrings=docstrings, index=1, parent=example)
+        return markdown
+
+    def get_contributions_markdown(self):
+        markdown = Markdown(header="Contributions")
+        markdown.add_lines(
+            "Issue-creation and discussion is most welcome!",
+            "",
+            "Pull requests are **not wanted**, please discuss with me before investing any time."
+        )
+        return markdown
+
+
+
+
+
+
+
+
+
+
+
+
+
