@@ -1,12 +1,10 @@
 
 
 from generalpackager import Packager
-from generalfile.test.setup_workdir import setup_workdir
 
-import unittest
+from generalfile.test.test_path import PathTest
 
-
-class TestPackager(unittest.TestCase):
+class TestPackager(PathTest):
     def test_badges_dict(self):
         self.assertLess(2, len(Packager().get_badges_dict()))
 
