@@ -1,7 +1,6 @@
-
+from generallibrary import Log
 
 from generalpackager import Packager
-from generalfile.test.setup_workdir import setup_workdir
 
 import unittest
 
@@ -17,11 +16,6 @@ class TestPackager(unittest.TestCase):
         packager = Packager()
         packager.general_bumped_set()
 
-        version = packager.localrepo.version
-        packager.localrepo.bump_version()
-        self.assertLess(0, len(packager.general_bumped_set()))
-        packager.localrepo.version = version
-
     def test_general_changed_dict(self):
         Packager().general_changed_dict()
 
